@@ -1,54 +1,72 @@
-grtslin <- function (shapefilename=NULL, linframe, samplesize=100, SiteBegin=1,
-   shift.grid=TRUE, startlev=NULL, maxlev=11){
-
 ################################################################################
 # Function: grtslin
-# Purpose: Select a generalized random-tesselation stratified (GRTS) sample of a
-#    linear resource
 # Programmers: Tony Olsen, Tom Kincaid, Don Stevens, Christian Platt,
 #   			Denis White, Richard Remington
 # Date: May 19, 2004
 # Last Revised: August 18, 2016
-# Description:      
-#   This function select a GRTS sample of a linear resource.  The function uses
-#   hierarchical randomization to ensure that the sample will include no more
-#   than one point per cell and then picks a point in selected cells.  
-# Arguments:
-#   shapefilename = name of the input shapefile.  If shapefilename equals NULL,
-#     then the shapefile or shapefiles in the working directory are used.  The
-#     default is NULL.
-#   linframe = a data frame containing id, mdcaty, and mdm.
-#   samplesize = number of points to select in the sample.  The default is 100.
-#   SiteBegin = first number to start siteID numbering.  The default is 1.
-#   shift.grid = the option to randomly shift the hierarchical grid.  The
-#     default is TRUE.
-#   startlev = initial number of hierarchical levels to use for the GRTS grid,
-#     which must be less than or equal to maxlev (if maxlev is specified) and
-#     cannot be greater than 11.  The default is NULL.
-#   maxlev = maximum number of hierarchical levels to use for the GRTS grid,
-#     which cannot be greater than 11.  The default is 11.
-# Results: 
-#   A data frame of sample points containing: siteID, id, x, y, mdcaty,
-#   and weight.
-# Other Functions Required:
-#   numLevels - C function to determine the number of levels for hierarchical
-#     randomization
-#   constructAddr - C function to construct the hierarchical address for all
-#     points
-#   ranho - C function to construct the randomized hierarchical address for all
-#     points
-#   pickGridCells - C function to select grid cells that get a sample point
-#   insideLinearGridCell - C function to determine ID value and clipped polyline
-#     length for shapefile records contained in the selected grid cells
-#   selectrecordID - select a shapefile record from which to select a sample
-#     point
-#   pickLinearSamplePoints - C function to pick sample points in the selected grid
-#     cells
+#
+#' Select a Generalized Random-Tesselation Stratified (GRTS) Sample of a Linear Resource
+#'
+#' This function select a GRTS sample of a linear resource.  The function uses
+#' hierarchical randomization to ensure that the sample will include no more
+#' than one point per cell and then picks a point in selected cells.
+#'
+#' @param shapefilename Name of the input shapefile.  If shapefilename equals
+#'   NULL, then the shapefile or shapefiles in the working directory are used.
+#'   The default is NULL.
+#'
+#' @param linframe Data frame containing id, mdcaty, and mdm.
+#'
+#' @param samplesize Number of points to select in the sample.  The default is
+#'   100.
+#'
+#' @param SiteBegin First number to start siteID numbering.  The default is 1.
+#'
+#' @param shift.grid Option to randomly shift the hierarchical grid.  The
+#'   default is TRUE.
+#'
+#' @param startlev Initial number of hierarchical levels to use for the GRTS
+#'   grid, which must be less than or equal to maxlev (if maxlev is specified)
+#'   and cannot be greater than 11.  The default is NULL.
+#'
+#' @param maxlev Maximum number of hierarchical levels to use for the GRTS
+#'   grid, which cannot be greater than 11.  The default is 11.
+#'
+#' @return Data frame of sample points containing: siteID, id, x, y, mdcaty,
+#'   and weight.
+#'
+#' @section Other Functions Required:
+#'   \describe{
+#'     \item{\code{numLevels}}{C function to determine the number of
+#'       levels for hierarchical randomization}
+#'     \item{\code{constructAddr}}{C function to construct the
+#'       hierarchical address for all points}
+#'     \item{\code{ranho}}{C function to construct the randomized
+#'       hierarchical address for all points}
+#'     \item{\code{pickGridCells}}{C function to select grid cells that
+#'       get a sample point}
+#'     \item{\code{insideLinearGridCell}}{C function to determine ID
+#'       value and clipped polyline length for shapefile records contained in
+#'       the selected grid cells}
+#'     \item{\code{\link{selectrecordID}}}{select a shapefile record from which
+#'       to select a sample point}
+#'     \item{\code{pickLinearSamplePoints}}{C function to pick sample
+#'       points in the selected grid cells}
+#'   }
+#'
+#' @author Tony Olsen \email{Olsen.Tony@epa.gov}
+#'
+#' @keywords survey
+#'
+#' @export
 ################################################################################
 
+grtslin <- function (shapefilename = NULL, linframe, samplesize = 100,
+   SiteBegin = 1, shift.grid = TRUE, startlev = NULL, maxlev = 1){
+
 # Ensure that the processor is little-endian
 
-   if(.Platform$endian == "big") 
+   if(.Platform$endian == "big")
       stop("\nA little-endian processor is required for the grtslin function.")
 
 # Determine the number of levels for hierarchical randomization
@@ -56,7 +74,7 @@ grtslin <- function (shapefilename=NULL, linframe, samplesize=100, SiteBegin=1,
    temp <- .Call("numLevels", shapefilename, samplesize, shift.grid,
       startlev, maxlev, linframe$id, linframe$mdm)
    if(is.null(temp[[1]]))
-      stop("\nAn error occured while determining the number of levels for hierarchical \nrandomization.") 
+      stop("\nAn error occured while determining the number of levels for hierarchical \nrandomization.")
    nlev <- temp$nlev
    dx <- temp$dx
    dy <- temp$dy
@@ -64,7 +82,7 @@ grtslin <- function (shapefilename=NULL, linframe, samplesize=100, SiteBegin=1,
    yc <- temp$yc
    cel.wt <- temp$cel.wt
    sint <- temp$sint
-        
+
 # Remove cells with zero weight
 
    indx <- cel.wt > 0
@@ -85,7 +103,7 @@ grtslin <- function (shapefilename=NULL, linframe, samplesize=100, SiteBegin=1,
    rord <- order(ranhadr)
 
 # Select grid cells that get a sample point
-        
+
    rstrt <- runif(1, 0, sint)
    ttl.wt <- c(0, cumsum(cel.wt[rord]))
    idx <- ceiling((ttl.wt - rstrt)/sint)
@@ -119,7 +137,7 @@ grtslin <- function (shapefilename=NULL, linframe, samplesize=100, SiteBegin=1,
    ycs <- temp$ycs
 
 # Construct sample line in reverse hierarchical order
- 
+
    nlv4 <- max(1, ceiling(logb(samplesize, 4)))
    rho <- matrix(0, 4^nlv4, nlv4)
    rv4 <- 0:3
@@ -127,8 +145,8 @@ grtslin <- function (shapefilename=NULL, linframe, samplesize=100, SiteBegin=1,
    for(i in 1:nlv4)
       rho[, i] <- rep(rep(rv4, rep(pwr4[i], 4)),pwr4[nlv4]/pwr4[i])
    rho4 <- rho%*%matrix(rev(pwr4), nlv4, 1)
-  
-# Place weighted points on line in reverse hierarchical order 
+
+# Place weighted points on line in reverse hierarchical order
 
    rh.ord <- unique(floor(rho4 * samplesize/4^nlv4)) + 1
    id <- id[rh.ord]
